.. :changelog:

Release History
------------------

0.2.0 (2015-04-14)
++++++++++++++++++

* Use common git files such as .gitignore, .gitmodules, .gitkeep and the .git 
  directory as default exclude patterns when building the rsync command

0.1.0 (2015-04-14)
++++++++++++++++++

* Initial public release
